package terminal;

import java.io.*;

public interface SafePipedStream {

    public static class SafePipedInputStream {

        private PipedInputStream underlyingStream;

        public SafePipedInputStream(PipedInputStream underlyingStream) {
            this.underlyingStream = underlyingStream;
        }

        public int read() {
            try {
                return underlyingStream.read();
            } catch (IOException e) {
                throw new UncheckedIOException(e);
            }
        }

        public void close() {
            try {
                underlyingStream.close();
            } catch (IOException e) {
                throw new UncheckedIOException(e);
            }
        }
    }

    public static class SafePipedOutputStream {

        private PipedOutputStream underlyingStream;

        public SafePipedOutputStream(PipedOutputStream underlyingStream) {
            this.underlyingStream = underlyingStream;
        }

        public void write(byte[] b) {
            try {
                underlyingStream.write(b);
            } catch (IOException e) {
                throw new UncheckedIOException(e);
            }
        }

        public void flush() {

            try {
                underlyingStream.flush();
            } catch (IOException e) {
                throw new UncheckedIOException(e);
            }
        }

        public void close() {
            try {
                underlyingStream.close();
            } catch (IOException e) {
                throw new UncheckedIOException(e);
            }
        }
    }

    public static class UncheckedIOException extends RuntimeException {

        private static final long serialVersionUID = 1L;
        private IOException exception;

        public UncheckedIOException(IOException exception) {
            this.exception = exception;
        }

        @Override
        public String getMessage() {
            return exception.getMessage();
        }
    }

}
